@@ -309,6 +309,18 @@ pglogical_worker_attach(int slot, PGLogicalWorkerType type)
 	Assert(slot >= 0);
 	Assert(slot < PGLogicalCtx->total_workers);
 
+	/*
+	 * Establish signal handlers. We must do this before unblocking the
+	 * signals. The default SIGTERM handler of Postgres's background
+	 * worker processes otherwise might throw a FATAL error, forcing us
+	 * to exit while potentially holding a spinlock and/or corrupt
+	 * shared memory.
+	 */
+	pqsignal(SIGTERM, handle_sigterm);
+
+	/* Now safe to process signals */
+	BackgroundWorkerUnblockSignals();
+
 	MyProcPort = (Port *) calloc(1, sizeof(Port));
 
 #if PG_VERSION_NUM < 90600
@@ -339,16 +351,12 @@ pglogical_worker_attach(int slot, PGLogicalWorkerType type)
 
 	LWLockRelease(PGLogicalCtx->lock);
 
-	/* Make it easy to identify our processes. */
-	SetConfigOption("application_name", MyBgworkerEntry->bgw_name,
-					PGC_USERSET, PGC_S_SESSION);
-
 	/* Establish signal handlers. */
 	BackgroundWorkerUnblockSignals();
 
 	/* Make it easy to identify our processes. */
 	SetConfigOption("application_name", MyBgworkerEntry->bgw_name,
-					PGC_USERSET, PGC_S_SESSION);
+					PGC_BACKEND, PGC_S_OVERRIDE);
 
 	/* Connect to database if needed. */
 	if (MyPGLogicalWorker->dboid != InvalidOid)
@@ -695,7 +703,12 @@ pglogical_worker_shmem_init(void)
 {
 	int			nworkers;
 
+#if PG_VERSION_NUM >= 150000
+	if (prev_shmem_request_hook)
+		prev_shmem_request_hook();
+#else
 	Assert(process_shared_preload_libraries_in_progress);
+#endif
 
 	/*
 	 * This is cludge for Windows (Postgres des not define the GUC variable
